.ace-github-light-default .ace_gutter {
    background: #ffffff;
    color: rgba(27, 31, 35, 0.3);
}

.ace-github-light-default .ace_print-margin {
    width: 1px;
    background: #e8e8e8;
}

.ace-github-light-default {
    background-color: #FFFFFF;
    color: #24292E;
}

.ace-github-light-default .ace_cursor {
    color: #044289;
    background: none;
}

.ace-github-light-default .ace_marker-layer .ace_selection {
    background: rgba(3, 102, 214, 0.14);
}

.ace-github-light-default.ace_multiselect .ace_selection.ace_start {
    box-shadow: 0 0 3px 0px #FFFFFF;
    border-radius: 2px;
}

.ace-github-light-default .ace_marker-layer .ace_step {
    background: rgb(198, 219, 174);
}

.ace-github-light-default .ace_marker-layer .ace_bracket {
    margin: -1px 0 0 -1px;
    border: 1px solid rgba(52, 208, 88, 0);
    background: rgba(52, 208, 88, 0.25);
}

.ace-github-light-default .ace_marker-layer .ace_active-line {
    background: #f6f8fa;
    border: 2px solid #eeeeee;
}

.ace-github-light-default .ace_gutter-active-line {
    background-color: #f6f8fa;
    color: #24292e
}

.ace-github-light-default .ace_marker-layer .ace_selected-word {
    border: 1px solid rgba(3, 102, 214, 0.14);
}

.ace-github-light-default .ace_fold {
    background-color: #D73A49;
    border-color: #24292E;
}

.ace_tooltip.ace-github-light-default {
    background-color: #f6f8fa !important;
    color: #444d56 !important;
    border: 1px solid #444d56
}

.ace-github-light-default .language_highlight_error {
    border-bottom: dotted 1px #cb2431;
    background: none;
}

.ace-github-light-default .language_highlight_warning {
    border-bottom: solid 1px #f9c513;
    background: none;
}

.ace-github-light-default .language_highlight_info {
    border-bottom: dotted 1px #1a85ff;
    background: none;
}

.ace-github-light-default .ace_keyword {
    color: #D73A49;
}

.ace-github-light-default .ace_constant {
    color: #005CC5;
}

.ace-github-light-default .ace_support {
    color: #005CC5;
}

.ace-github-light-default .ace_support.ace_constant {
    color: #005CC5;
}

.ace-github-light-default .ace_support.ace_type {
    color: #D73A49;
}

.ace-github-light-default .ace_storage {
    color: #D73A49;
}

.ace-github-light-default .ace_storage.ace_type {
    color: #D73A49;
}

.ace-github-light-default .ace_invalid.ace_illegal {
    font-style: italic;
    color: #B31D28;
}

.ace-github-light-default .ace_invalid.ace_deprecated {
    font-style: italic;
    color: #B31D28;
}

.ace-github-light-default .ace_string {
    color: #032F62;
}

.ace-github-light-default .ace_string.ace_regexp {
    color: #032F62;
}

.ace-github-light-default .ace_comment {
    color: #6A737D;
}

.ace-github-light-default .ace_variable {
    color: #E36209;
}

.ace-github-light-default .ace_variable.ace_language {
    color: #005CC5;
}

.ace-github-light-default .ace_entity.ace_name {
    color: #6F42C1;
}

.ace-github-light-default .ace_entity {
    color: #6F42C1;
}

.ace-github-light-default .ace_entity.ace_name.ace_tag {
    color: #22863A;
}

.ace-github-light-default .ace_meta.ace_tag {
    color: #22863A;
}

.ace-github-light-default .ace_markup.ace_heading {
    color: #005CC5;
}

.ace-github-light-default .ace_indent-guide {
  background: url("../github_light_default-1.png") right repeat-y;
}

.ace-github-light-default .ace_indent-guide-active {
  background: url("../github_light_default-2.png") right repeat-y;
}
